# Rapport des Vulnérabilités des Dépendances

_Généré le 2025-11-21 19:39:55_

**Total:** 2 vulnérabilité(s)

## MEDIUM (2)

### requests@2.31.0

- **ID:** GHSA-9hjg-9r4m-mvj7
- **CVE:** CVE-2024-47081
- **Description:** Requests vulnerable to .netrc credentials leak via malicious URLs
- **Versions affectées:** Toutes les versions

### requests@2.31.0

- **ID:** GHSA-9wx4-h78v-vm56
- **CVE:** CVE-2024-35195
- **Description:** Requests `Session` object does not verify requests after making first request with verify=False
- **Versions affectées:** Toutes les versions
